@@ -14,11 +14,13 @@ from ._models import (
     LogLevel,
     ThrottleRule,
 )
+from ._replay._models import GracyRecording
+from ._replay._storages import GracyReplay, GracyReplayStorage, SQLiteReplayStorage
 from ._reports._models import GracyAggregatedRequest, GracyAggregatedTotal, GracyReport
 
 logging.basicConfig(level=logging.INFO, format="%(asctime)s %(message)s")
 
-__version__ = "1.6.1"
+__version__ = "1.7.0"
 
 __all__ = [
     "exceptions",
@@ -35,6 +37,11 @@ __all__ = [
     "ThrottleRule",
     "GracyConfig",
     "DEFAULT_CONFIG",
+    # Replay
+    "GracyRecording",
+    "GracyReplay",
+    "GracyReplayStorage",
+    "SQLiteReplayStorage",
     # Reports
     "GracyReport",
     "GracyAggregatedTotal",
